rm(list=ls())

#First we will read in the packages needed for the analysis
library(metafor)
library(robumeta)


#PLEASE READ
#First, note the following:
#in the data set, the Study_info column indicates author information
#the study_id column indicates study identifiers (multiple effects clustered under one study using the same study ID when necessary)
#the Task_Group column indicates which task type the effect comes from (more information below in the moderation analysis part of the script)
#the Auditory_1 column indicates if the stimulus was auditory (1) or non auditory (0)
#the Verbal_1 column indicates if the required response was verbal (1) or non verbal 
#the Linguistic_1 column indicates if the stimulus was linguistic (1) or non linguistic (0)
#N_SLI is the sample size for the clinical group; N_Control is the sample size for the neuro-typical group
#Age_SLI is the mean age for the clinical group; Year of Publication is the year of publication (if unpublished, this is the year listed on the dissertation)
#The rest of the columns are the descriptives necessary for running the meta analysis:
#the mean RT from each group and their associated standard deviations

#Full Data set with outlier included
#A forest plot is ran below, which is how we knew we had outlying effects (see details below)

dat_DLD_data1 <- read.csv("DLD_full_dataset3.csv",header=T)
View(dat_DLD_data1)
dat_DLD_data1 <- escalc(measure = "SMD", # Tells R to calculate standardized mean-difference (Hedges' g) escalc is metafor function
                        m1i = Mean_SLI, m2i = Mean_control, # Clinical and control means
                        sd1i = SD_SLI, sd2i = SD_control, # Clinical and control SDs
                        n1i = N_SLI, n2i = N_Control, # Clinical and control sample size
                        data = dat_DLD_data1, # Dataset
                        append = TRUE) # Tell R to put ES and var in current dataset
View(dat_DLD_data1)

#Output effects for Table 1 (Effect Table)
write.csv(dat_DLD_data1, "Effect_Table.csv")

#Run Descriptives on DLD Age
median.age=median(dat_DLD_data1$Age_SLI, na.rm=T)
mean.age=mean(dat_DLD_data1$Age_SLI, na.rm=T)
range.age=range(dat_DLD_data1$Age_SLI, na.rm=T)

#This is the main meta-analysis on the full data set
rve_DLD_data1 <- robu(formula = yi ~ 1, 
                      var.eff.size = vi, 
                      studynum = study_id,
                      data = dat_DLD_data1, 
                      modelweights = "CORR",
                      rho = 0.8)
print(rve_DLD_data1)

sensitivity(rve_DLD_data1)

#We have ran the main meta-analysis, let's see if there are outliers 
#Forest plot on the full data set; this is used to screen for outliers > |-2|
forest_DLD_1 <- rma(yi = yi, vi = vi, data = dat_DLD_data1, method = "REML",
                    slab = Study_info)
forest(forest_DLD_1)

forest(forest_DLD_1, order= "obs")

#Funnel plot for full data set, and publication bias
re_funnel <- rma(yi=yi, vi=vi, data = dat_DLD_data1, method = "REML")
funnel(re_funnel)

regtest(re_funnel, model = "rma", predictor = "sei")

#Since we detected an outlying study (with two effects), we can remove it and rerun the meta-analysis
#META ANALYSIS WITHOUT OUTLIER

#Read in the data set with the outlier removed
dat_DLD_data2 <- read.csv("DLD_OutliersRemoved_Dataset3.csv",header=T)
View(dat_DLD_data2) 
dat_DLD_data2 <- escalc(measure = "SMD", # Tells R to calculate standardized mean-difference (Hedges' g) escalc is metafor function
                        m1i = Mean_SLI, m2i = Mean_control, # Clinical and control means
                        sd1i = SD_SLI, sd2i = SD_control, # Clinical and control SDs
                        n1i = N_SLI, n2i = N_Control, # Clinical and control sample size
                        data = dat_DLD_data2, # Dataset
                        append = TRUE) # Tell R to put ES and var in current dataset
View(dat_DLD_data2)

#Age Descriptives with outlier removed, they are consistent with full data set
median.age=median(dat_DLD_data2$Age_SLI, na.rm=T)
mean.age=mean(dat_DLD_data2$Age_SLI, na.rm=T)
range.age=range(dat_DLD_data2$Age_SLI, na.rm=T)

#Main meta-analysis with outlier removed
rve_DLD_data2 <- robu(formula = yi ~ 1, 
                      var.eff.size = vi, 
                      studynum = study_id,
                      data = dat_DLD_data2, 
                      modelweights = "CORR",
                      rho = 0.8)
print(rve_DLD_data2)


#Forest plot on the data set with outliers removed
forest_DLD_2 <- rma(yi = yi, vi = vi, data = dat_DLD_data2, method = "REML",
                    slab = Study_info)
forest(forest_DLD_2)

forest(forest_DLD_2, order= "obs")

#Funnel plot for data set with outliers removed, and publication bias
re_funnel2 <- rma(yi=yi, vi=vi, data = dat_DLD_data2, method = "REML")
funnel(re_funnel2)

regtest(re_funnel2, model = "rma", predictor = "sei")

#Moderation analyses on data set with outliers removed

#Age
age.center= dat_DLD_data2$Age_SLI - mean.age

rve_DLD_age_2 <- robu(formula = yi ~ (age.center),
                      var.eff.size = vi,
                      studynum = study_id,
                      data = dat_DLD_data2)
print(rve_DLD_age_2)

#This model is the same as above, just utilizing the scale function in R to check our work above
rve_DLD1_age_2.1 <- robu(formula = yi ~ scale(Age_SLI, center=T, scale=F),
                         var.eff.size = vi,
                         studynum = study_id,
                         data = dat_DLD_data2)
print(rve_DLD1_age_2.1)

#Stimulus Modality
#In the data set, 0 = non-auditory, 1 = auditory
rve_auditory_2<- robu(formula = yi ~factor(Auditory_1), 
                      var.eff.size = vi,
                      studynum = study_id,
                      data = dat_DLD_data2)
print(rve_auditory_2)

#Response Modality 
#In the data set, 0 = non-verbal, 1 = verbal
rve_verbal_2<- robu(formula = yi ~factor(Verbal_1), 
                    var.eff.size = vi,
                    studynum = study_id,
                    data = dat_DLD_data2)
print(rve_verbal_2)

#Stimulus Type
#In the data set, 0 = non-linguistic, 1 = linguistic
rve_ling_2<- robu(formula = yi ~factor(Ling_1), 
                  var.eff.size = vi,
                  studynum = study_id,
                  data = dat_DLD_data2)
print(rve_ling_2)

#Task Group
#In the data set, 0 = Simple RT, 1 = Choice RT, 2 = Naming, 3 = Interference Control
rve_task_2<- robu(formula = yi ~factor(Task_Group), 
                  var.eff.size = vi,
                  studynum = study_id,
                  data = dat_DLD_data2)
print(rve_task_2)

#Publication Year
pub.center= dat_DLD_data2$Year.of.Publication - mean(dat_DLD_data2$Year.of.Publication)

rve_DLD_pubyr2 <- robu(formula = yi ~ (pub.center),
                       var.eff.size = vi,
                       studynum = study_id,
                       data = dat_DLD_data2)
print(rve_DLD_pubyr2)


#Subgroup analyses with outlying study removed

### Stimulus Modality ###

#NON AUDITORY 
dat_DLD_nonauditory_2 <- subset(dat_DLD_data2, dat_DLD_data2$Auditory_1 == 0)
View(dat_DLD_nonauditory_2)

rve_DLD_nonauditory_2 <- robu(formula = yi ~ 1, 
                              var.eff.size = vi, 
                              studynum = study_id,
                              data = dat_DLD_nonauditory_2, 
                              modelweights = "CORR",
                              rho = 0.8)
print(rve_DLD_nonauditory_2)

#AUDITORY 
dat_DLD_auditory_2 <- subset(dat_DLD_data2, dat_DLD_data2$Auditory_1 == 1)
View(dat_DLD_auditory_2)

rve_DLD_auditory_2 <- robu(formula = yi ~ 1, 
                           var.eff.size = vi, 
                           studynum = study_id,
                           data = dat_DLD_auditory_2, 
                           modelweights = "CORR",
                           rho = 0.8)
print(rve_DLD_auditory_2)

### Response Modality ###

#NON VERBAL
dat_DLD_nonverbal_2 <- subset(dat_DLD_data2, dat_DLD_data2$Verbal_1 == 0)
View(dat_DLD_nonverbal_2)

rve_DLD_nonverbal_2 <- robu(formula = yi ~ 1, 
                            var.eff.size = vi, 
                            studynum = study_id,
                            data = dat_DLD_nonverbal_2, 
                            modelweights = "CORR",
                            rho = 0.8)
print(rve_DLD_nonverbal_2)

#VERBAL
dat_DLD_verbal_2 <- subset(dat_DLD_data2, dat_DLD_data2$Verbal_1 == 1)
View(dat_DLD_verbal_2)

rve_DLD_verbal_2 <- robu(formula = yi ~ 1, 
                         var.eff.size = vi, 
                         studynum = study_id,
                         data = dat_DLD_verbal_2, 
                         modelweights = "CORR",
                         rho = 0.8)
print(rve_DLD_verbal_2)

#Stimulus Type ###

#NON LINGUISTIC
dat_DLD_nonling_2 <- subset(dat_DLD_data2, dat_DLD_data2$Ling_1 == 0)
View(dat_DLD_nonling_2)

rve_DLD_nonling_2 <- robu(formula = yi ~ 1, 
                          var.eff.size = vi, 
                          studynum = study_id,
                          data = dat_DLD_nonling_2, 
                          modelweights = "CORR",
                          rho = 0.8)
print(rve_DLD_nonling_2)

#LINGUISTIC
dat_DLD_ling_2 <- subset(dat_DLD_data2, dat_DLD_data2$Ling_1 == 1)
View(dat_DLD_ling_2)

rve_DLD_ling_2 <- robu(formula = yi ~ 1, 
                       var.eff.size = vi, 
                       studynum = study_id,
                       data = dat_DLD_ling_2, 
                       modelweights = "CORR",
                       rho = 0.8)
print(rve_DLD_ling_2)

### Task Category ###

#SIMPLE RT
dat_DLD_simpleRT <- subset(dat_DLD_data2, dat_DLD_data2$Task_Group == 0)
View(dat_DLD_simpleRT)

rve_DLD_simpleRT <- robu(formula = yi ~ 1, 
                         var.eff.size = vi, 
                         studynum = study_id,
                         data = dat_DLD_simpleRT, 
                         modelweights = "CORR",
                         rho = 0.8)
print(rve_DLD_simpleRT)

#CHOICE RT
dat_DLD_cRT <- subset(dat_DLD_data2, dat_DLD_data2$Task_Group == 1)
View(dat_DLD_cRT)

rve_DLD_cRT <- robu(formula = yi ~ 1, 
                    var.eff.size = vi, 
                    studynum = study_id,
                    data = dat_DLD_cRT, 
                    modelweights = "CORR",
                    rho = 0.8)
print(rve_DLD_cRT)

#NAMING 
dat_DLD_nam_2 <- subset(dat_DLD_data2, dat_DLD_data2$Task_Group == 2)
View(dat_DLD_nam_2)

rve_DLD_nam_2 <- robu(formula = yi ~ 1, 
                      var.eff.size = vi, 
                      studynum = study_id,
                      data = dat_DLD_nam_2, 
                      modelweights = "CORR",
                      rho = 0.8)
print(rve_DLD_nam_2)

#INTERFERENCE CONTROL
dat_DLD_intCRT <- subset(dat_DLD_data2, dat_DLD_data2$Task_Group == 3)
View(dat_DLD_intCRT)

rve_DLD_intCRT <- robu(formula = yi ~ 1, 
                       var.eff.size = vi, 
                       studynum = study_id,
                       data = dat_DLD_intCRT, 
                       modelweights = "CORR",
                       rho = 0.8)
print(rve_DLD_intCRT)










